@@ -4,6 +4,7 @@
 */
 
 #include "kcalc_parser.h"
+#include "kcalc_debug.h"
 #include "kcalc_token.h"
 #include "knumber/knumber.h"
 
@@ -15,6 +16,18 @@
 #include <QRegularExpressionMatch>
 #include <QString>
 
+const QString KCalcParser::BINARY_DIGITS_PATTERN = QStringLiteral("[0-1]{1,}");
+const QString KCalcParser::OCTAL_DIGITS_PATTERN = QStringLiteral("[0-7]{1,}");
+const QString KCalcParser::HEX_DIGITS_PATTERN = QStringLiteral("[0-9A-Fa-f]{1,}");
+
+const QString KCalcParser::DECIMAL_NUMBER_PATTERN = QLatin1String("(0*)((\\d*)[.,]?\\d+([e|E]([+-]?\\d+))?)");
+
+const QRegularExpression KCalcParser::BINARY_NUMBER_DIGITS_REGEX = QRegularExpression(KCalcParser::BINARY_DIGITS_PATTERN);
+const QRegularExpression KCalcParser::OCTAL_NUMBER_DIGITS_REGEX = QRegularExpression(KCalcParser::OCTAL_DIGITS_PATTERN);
+const QRegularExpression KCalcParser::HEX_NUMBER_DIGITS_REGEX = QRegularExpression(KCalcParser::HEX_DIGITS_PATTERN);
+
+const QRegularExpression KCalcParser::DECIMAL_NUMBER_REGEX = QRegularExpression(KCalcParser::DECIMAL_NUMBER_PATTERN);
+
 //------------------------------------------------------------------------------
 // Name: KCalcParser
 // Desc: constructor
@@ -35,7 +48,7 @@ KCalcParser::~KCalcParser() = default;
 //------------------------------------------------------------------------------
 KCalcToken::TokenCode KCalcParser::stringToToken(const QString &buffer, int &index, int base)
 {
-    qDebug() << "Converting string to Token ";
+    qCDebug(KCALC_LOG) << "Converting string to Token ";
 
     int maxTokenLength = (index + 5 > buffer.size()) ? buffer.size() - index : 5;
     QString s = buffer.sliced(index, maxTokenLength);
@@ -48,12 +61,13 @@ KCalcToken::TokenCode KCalcParser::stringToToken(const QString &buffer, int &ind
 
     if (s.startsWith(HEX_NUMBER_PREFIX_STR)) {
         QRegularExpressionMatch match;
-        int numIndex = buffer.indexOf(QRegularExpression(QLatin1String("0x[0-9A-F]{1,}")), index, &match);
-        if (numIndex == index) {
-            token_KNumber_ = match.captured();
+        int numIndex = buffer.indexOf(HEX_NUMBER_DIGITS_REGEX, index + HEX_NUMBER_PREFIX_STR.length(), &match);
+        if (numIndex == index + HEX_NUMBER_PREFIX_STR.length()) {
+            token_KNumber_ = HEX_NUMBER_PREFIX_STR + match.captured();
             if (match.captured().size() > 16) {
                 return KCalcToken::TokenCode::INVALID_TOKEN;
             }
+            index += HEX_NUMBER_PREFIX_STR.length();
             index += match.captured().size();
             return KCalcToken::TokenCode::KNUMBER;
         } else {
@@ -63,12 +77,13 @@ KCalcToken::TokenCode KCalcParser::stringToToken(const QString &buffer, int &ind
 
     if (s.startsWith(BINARY_NUMBER_PREFIX_STR)) {
         QRegularExpressionMatch match;
-        int numIndex = buffer.indexOf(QRegularExpression(QLatin1String("0b[0-1]{1,}")), index, &match);
-        if (numIndex == index) {
-            token_KNumber_ = match.captured();
+        int numIndex = buffer.indexOf(BINARY_NUMBER_DIGITS_REGEX, index + BINARY_NUMBER_PREFIX_STR.length(), &match);
+        if (numIndex == index + BINARY_NUMBER_PREFIX_STR.length()) {
+            token_KNumber_ = BINARY_NUMBER_PREFIX_STR + match.captured();
             if (match.captured().size() > 64) {
                 return KCalcToken::TokenCode::INVALID_TOKEN;
             }
+            index += BINARY_NUMBER_PREFIX_STR.length();
             index += match.captured().size();
             return KCalcToken::TokenCode::KNUMBER;
         } else {
@@ -78,12 +93,13 @@ KCalcToken::TokenCode KCalcParser::stringToToken(const QString &buffer, int &ind
 
     if (s.startsWith(OCTAL_NUMBER_PREFIX_STR)) {
         QRegularExpressionMatch match;
-        int numIndex = buffer.indexOf(QRegularExpression(QLatin1String("0[0-7]{1,}")), index, &match);
-        if (numIndex == index) {
-            token_KNumber_ = match.captured();
+        int numIndex = buffer.indexOf(OCTAL_NUMBER_DIGITS_REGEX, index + OCTAL_NUMBER_PREFIX_STR.length(), &match);
+        if (numIndex == index + OCTAL_NUMBER_PREFIX_STR.length()) {
+            token_KNumber_ = OCTAL_NUMBER_PREFIX_STR_C_STYLE + match.captured();
             if (match.captured().size() > 21) {
                 return KCalcToken::TokenCode::INVALID_TOKEN;
             }
+            index += OCTAL_NUMBER_PREFIX_STR.length();
             index += match.captured().size();
             return KCalcToken::TokenCode::KNUMBER;
         }
@@ -98,26 +114,39 @@ KCalcToken::TokenCode KCalcParser::stringToToken(const QString &buffer, int &ind
         QRegularExpressionMatch match;
         switch (base) {
         case 2:
-            numIndex = buffer.indexOf(QRegularExpression(QLatin1String("[0-1]{1,}")), index, &match);
+            numIndex = buffer.indexOf(BINARY_NUMBER_DIGITS_REGEX, index, &match);
             token_KNumber_ = BINARY_NUMBER_PREFIX_STR;
+            if (match.captured().size() > 64) {
+                return KCalcToken::TokenCode::INVALID_TOKEN;
+            }
             break;
         case 8:
-            numIndex = buffer.indexOf(QRegularExpression(QLatin1String("[0-7]{1,21}")), index, &match);
-            token_KNumber_ = OCTAL_NUMBER_PREFIX_STR;
+            numIndex = buffer.indexOf(OCTAL_NUMBER_DIGITS_REGEX, index, &match);
+            token_KNumber_ = OCTAL_NUMBER_PREFIX_STR_C_STYLE;
+            if (match.captured().size() > 21) {
+                return KCalcToken::TokenCode::INVALID_TOKEN;
+            }
             break;
         case 10:
-            numIndex = buffer.indexOf(QRegularExpression(QLatin1String("(\\d*)[.,]?\\d+(e([+-]?\\d+))?")), index, &match);
+            numIndex = buffer.indexOf(DECIMAL_NUMBER_REGEX, index, &match);
             token_KNumber_.clear();
             break;
         case 16:
-            numIndex = buffer.indexOf(QRegularExpression(QLatin1String("[0-9A-F]{1,16}")), index, &match);
+            numIndex = buffer.indexOf(HEX_NUMBER_DIGITS_REGEX, index, &match);
             token_KNumber_ = HEX_NUMBER_PREFIX_STR;
+            if (match.captured().size() > 16) {
+                return KCalcToken::TokenCode::INVALID_TOKEN;
+            }
             break;
         default:
             break;
         }
         if (numIndex == index) {
-            token_KNumber_ += match.captured();
+            if (base == 10) {
+                token_KNumber_ += match.captured(2);
+            } else {
+                token_KNumber_ += match.captured();
+            }
             index += match.captured().size();
             return KCalcToken::TokenCode::KNUMBER;
         } else {
@@ -451,8 +480,8 @@ KCalcParser::ParsingResult KCalcParser::stringToTokenQueue(const QString &buffer
     m_inputHasConstants = false;
     int buffer_index = 0;
     int buffer_size = buffer.size();
-    qDebug() << "Parsing string to TokenQueue";
-    qDebug() << "Buffer string to parse: " << buffer;
+    qCDebug(KCALC_LOG) << "Parsing string to TokenQueue";
+    qCDebug(KCALC_LOG) << "Buffer string to parse: " << buffer;
 
     KCalcToken::TokenCode tokenCode = KCalcToken::TokenCode::INVALID_TOKEN;
 
@@ -479,7 +508,7 @@ KCalcParser::ParsingResult KCalcParser::stringToTokenQueue(const QString &buffer
         }
 
         if (tokenCode == KCalcToken::TokenCode::KNUMBER) {
-            qDebug() << "String KNumber converted: " << token_KNumber_;
+            qCDebug(KCALC_LOG) << "String KNumber converted: " << token_KNumber_;
             token_KNumber_.replace(COMMA_STR, KNumber::decimalSeparator());
             token_KNumber_.replace(POINT_STR, KNumber::decimalSeparator());
             operand = KNumber(token_KNumber_);
@@ -487,22 +516,30 @@ KCalcParser::ParsingResult KCalcParser::stringToTokenQueue(const QString &buffer
             tokenQueue.enqueue(KCalcToken(operand, buffer_index));
         } else {
             tokenQueue.enqueue(KCalcToken(tokenCode, buffer_index));
-            qDebug() << "KCalcToken converted with code: " << tokenCode;
+            qCDebug(KCALC_LOG) << "KCalcToken converted with code: " << tokenCode;
         }
 
-        qDebug() << "Parsing index after this previous step: " << buffer_index;
+        qCDebug(KCALC_LOG) << "Parsing index after this previous step: " << buffer_index;
     }
 
-    qDebug() << "Parsing done, index after parsing: " << buffer_index;
+    qCDebug(KCALC_LOG) << "Parsing done, index after parsing: " << buffer_index;
 
-    if (tokenQueue.length() > 1) {
+    if (tokenQueue.length() > 2) {
         return ParsingResult::SUCCESS;
-    } else {
+    } else if (tokenQueue.length() == 2) {
+        if (!m_inputHasConstants && tokenQueue.first().getTokenCode() == KCalcToken::TokenCode::MINUS && tokenQueue.at(1).isKNumber()) {
+            return ParsingResult::SUCCESS_SINGLE_KNUMBER;
+        } else {
+            return ParsingResult::SUCCESS;
+        }
+    } else if (tokenQueue.length() == 1) {
         if (!m_inputHasConstants && tokenQueue.first().isKNumber()) {
             return ParsingResult::SUCCESS_SINGLE_KNUMBER;
         } else {
             return ParsingResult::SUCCESS;
         }
+    } else {
+        return ParsingResult::EMPTY;
     }
 }
 
